==> babel-plugin-incremental-dom-3.0.3.tgz: package/test/fixtures/prefix/all-together-now/expected.js <==
var _renderArbitrary = function _renderArbitrary(child) {
  var type = typeof child;

  if (type === "number" || type === "string" || child && child instanceof String) {
    IncrementalDOM.text(child);
  } else if (type === "function" && child.__jsxDOMWrapper) {
    child();
  } else if (Array.isArray(child)) {
    child.forEach(_renderArbitrary);
  } else if (String(child) === "[object Object]") {
    _forOwn(child, _renderArbitrary);
  }
};

var _attr = function _attr(value, name) {
  IncrementalDOM.attr(name, value);
};

var _hasOwn = Object.prototype.hasOwnProperty;

var _forOwn = function _forOwn(object, iterator) {
  for (var prop in object) {
    if (_hasOwn.call(object, prop)) iterator(object[prop], prop);
  }
};

function render() {
  IncrementalDOM.elementOpen("div");
  IncrementalDOM.elementOpenStart("div");

  _forOwn(props, _attr);

  IncrementalDOM.elementOpenEnd("div");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpenStart("div");

  _forOwn(props, _attr);

  IncrementalDOM.elementOpenEnd("div");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpen("div");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpen("div");
  IncrementalDOM.text("value");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpen("div");
  IncrementalDOM.text("3");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpen("div");

  _renderArbitrary(value);

  IncrementalDOM.elementClose("div");
  return IncrementalDOM.elementClose("div");
}

==> babel-plugin-incremental-dom-3.3.0.tgz: package/test/fixtures/prefix/all-together-now/expected.js <==
var _renderArbitrary = function _renderArbitrary(child) {
  var type = typeof child;

  if (type === "number" || type === "string" || type === "object" && child instanceof String) {
    IncrementalDOM.text(child);
  } else if (type === "function" && child.__jsxDOMWrapper) {
    child();
  } else if (Array.isArray(child)) {
    child.forEach(_renderArbitrary);
  } else if (type === "object" && String(child) === "[object Object]") {
    _forOwn(child, _renderArbitrary);
  }
};

var _attr = function _attr(value, name) {
  IncrementalDOM.attr(name, value);
};

var _hasOwn = Object.prototype.hasOwnProperty;

var _forOwn = function _forOwn(object, iterator) {
  for (var prop in object) {
    if (_hasOwn.call(object, prop)) iterator(object[prop], prop);
  }
};

function render() {
  IncrementalDOM.elementOpen("div");
  IncrementalDOM.elementOpenStart("div");

  _forOwn(props, _attr);

  IncrementalDOM.elementOpenEnd("div");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpenStart("div");

  _forOwn(props, _attr);

  IncrementalDOM.elementOpenEnd("div");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpen("div");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpen("div");
  IncrementalDOM.text("value");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpen("div");
  IncrementalDOM.text("3");
  IncrementalDOM.elementClose("div");
  IncrementalDOM.elementOpen("div");

  _renderArbitrary(value);

  IncrementalDOM.elementClose("div");
  return IncrementalDOM.elementClose("div");
}
